#
# spec file for package parsec-tool
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
%define archive_version 0.7.0

%{?systemd_ordering}
Name:           parsec-tool
Version:        0.7.0
Release:        1.3
Summary:        Platform AbstRaction for SECurity
License:        Apache-2.0
URL:            https://github.com/parallaxsecond/parsec-tool
Source0:        https://github.com/parallaxsecond/parsec-tool/archive/%{archive_version}.tar.gz#/parsec-tool-%{archive_version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  protobuf-devel
Requires:       parsec
ExcludeArch:    %{ix86} armv6l armv6hl

%description
A tool to communicate with the Parsec service on the command-line.

%prep
%setup -qa1 -n parsec-tool-%{archive_version}
rm -rf .cargo && mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
export PROTOC=/usr/bin/protoc
%cargo_build

%install
%cargo_install
# Install parsec-tool in the right directory
mkdir %{buildroot}%{_bindir} && mv .cargo/bin/* %{buildroot}%{_bindir}
# Clean-up
find %{buildroot} -name .crates2.json -delete
rm -rf %{buildroot}%{_datadir}/cargo/registry

%files
%license LICENSE
%doc README.md
%{_bindir}/parsec-tool

%changelog
* Mon Oct 30 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.7.0:
  * No real changes since rc1
* Tue Oct 17 2023 Guillaume <guillaume@arm.com>
- Update to 0.7.0-rc1:
  * Changelog: https://github.com/parallaxsecond/parsec-tool/compare/0.6.0...0.7.0-rc1
* Thu Apr 20 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.6.0:
  * Update (embedded) changelog
* Tue Mar 28 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.6.0-rc2:
  * Align crates version with parsec-service
* Thu Mar 23 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.6.0-rc1:
  * Bump parsec-client
  * Allow to exclude algorithms for encryption/decryption tests
  * Add support for RSA OAEP into parsec-tool and parsec-cli-tests.sh
  * Fix clippy needless_borrow warnings
  * Update lib.rs to remove const_err
- Add <param name="update">true</param> to _service to apply
  security updates
- Use cargo-packaging for all flavors
- Enable cargo_audit
* Wed Apr  6 2022 Marcus Meissner <meissner@suse.com>
- use cargo-packaging (bsc#1198130)
* Thu Mar 31 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable build on x86 to follow parsec package
* Mon Mar 21 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.5.2:
  * changelog from 0.5.1 to 0.5.2:
    https://github.com/parallaxsecond/parsec-tool/compare/0.5.1...0.5.2
  * Fixes CVE-2022-24713 - boo#1196972
* Thu Feb 24 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.5.1:
  * changelog from 0.4.0 to 0.5.1:
    https://github.com/parallaxsecond/parsec-tool/compare/0.4.0...0.5.1
* Thu Jan 13 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.4.0:
  * changelog from 0.3.1 to 0.4.0:
    https://github.com/parallaxsecond/parsec-tool/compare/0.3.1...0.4.0
* Tue Sep 21 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.3.1:
  * changelog from 0.3.0 to 0.3.1:
    https://github.com/parallaxsecond/parsec-tool/compare/0.3.0...0.3.1
* Wed Mar 31 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.3.0:
  * changelog from 0.2 to 0.3:
    https://github.com/parallaxsecond/parsec-tool/compare/0.2.0...0.3.0
  * changelog from skipped 0.1 to 0.2:
    https://github.com/parallaxsecond/parsec-tool/compare/0.1.0...0.2.0
* Thu Nov 26 2020 Andreas Schwab <schwab@suse.de>
- BuildRequire protobuf-devel for protoc
* Fri Oct 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Initial version 0.1.0
